package com.ruoyi.learn.service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import com.ruoyi.learn.domain.LearnQuestions;

/**
 * 试题Service接口
 *
 * @author ruoyi
 * @date 2025-09-18
 */
public interface ILearnQuestionsService
{
    /**
     * 查询试题
     *
     * @param id 试题主键
     * @return 试题
     */
    public LearnQuestions selectLearnQuestionsById(Long id);

    /**
     * 查询试题列表
     *
     * @param learnQuestions 试题
     * @return 试题集合
     */
    public List<LearnQuestions> selectLearnQuestionsList(LearnQuestions learnQuestions);

    /**
     * 新增试题
     *
     * @param learnQuestions 试题
     * @return 结果
     */
    public int insertLearnQuestions(LearnQuestions learnQuestions);

    /**
     * 修改试题
     *
     * @param learnQuestions 试题
     * @return 结果
     */
    public int updateLearnQuestions(LearnQuestions learnQuestions);

    /**
     * 批量删除试题
     *
     * @param ids 需要删除的试题主键集合
     * @return 结果
     */
    public int deleteLearnQuestionsByIds(Long[] ids);

    /**
     * 删除试题信息
     *
     * @param id 试题主键
     * @return 结果
     */
    public int deleteLearnQuestionsById(Long id);

    int updateQuestionType(String type, Collection<Long> ids);

    public List<LearnQuestions> selectCollectedList(LearnQuestions questions);

    public void fillCollectInfo(Long userId, List<LearnQuestions> questions);
    public List<LearnQuestions> selectQuestionByPaperId(Long paperId);

    public void fillQuestionInfo(List<LearnQuestions> list,Boolean isFillTitleOption);

    public String correctImageUrl(String content);
    public List<LearnQuestions> selectLearnQuestionsByIds(Long[] ids);

    public List<LearnQuestions> statByKnowledgeType(Map cond);
//    public List<LearnQuestions> statByKnowledge(Map cond);
//    public List<LearnQuestions> selectCollectInfo(Map<String, Object> map);

    public List<LearnQuestions> selectQuestionsForPaper(LearnQuestions cond);


}
